package com.endeavour.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import com.endeavour.model.Musica;

public class MusicaDAO {
	private Connection con;

	public MusicaDAO() throws SQLException {
		this.con = ConnectionFactory.getConnection();
	}

	public void adiciona(Musica musica) throws SQLException {
		// prepared statement para inserção

		String sql = "insert into Musicas (codalbum,codidioma,titulo,txtletra,ultimaAtualizacao,codusuario) values (?,?,?,?,?,?)";
		PreparedStatement stmt = con.prepareStatement(sql);

		// seta os valores
		stmt.setLong(1, musica.getCodalbum());
		stmt.setLong(2, musica.getCodidioma());
		stmt.setString(3, musica.getTitulo());
		stmt.setString(4, musica.getTxtletra());
		stmt.setObject(5, new Timestamp(Calendar.getInstance()
				.getTimeInMillis()));
		// Default do primeiro usuário cadastrado
		stmt.setLong(6, 0);

		// executa
		stmt.execute();
		stmt.close();
	}

	public List<Musica> getLista(int codalbum) throws SQLException {

		PreparedStatement stmt = this.con
				.prepareStatement("select * from Musicas where codalbum = ? ");
		stmt.setInt(1, codalbum);

		ResultSet rs = stmt.executeQuery();

		List<Musica> Musicas = new ArrayList<Musica>();

		while (rs.next()) {
			// criando o objeto Musica
			Musica musica = new Musica();
			musica.setCodmusica(rs.getInt("codmusica"));
			musica.setTitulo(rs.getString("titulo"));
			musica.setTxtletra(rs.getString("txtletra"));
			// adicionando o objeto à lista
			Musicas.add(musica);
		}

		rs.close();
		stmt.close();

		return Musicas;
	}

	public Musica getMusica(int codmusica) throws SQLException {

		PreparedStatement stmt = this.con
				.prepareStatement("select txtletra from Musicas where codmusica = ? ");
		stmt.setInt(1, codmusica);

		ResultSet rs = stmt.executeQuery();

		Musica musica = new Musica();
		rs.next();
		musica.setTxtletra(rs.getString("txtletra"));

		rs.close();
		stmt.close();

		return musica;
	}
	
	public void atualiza(Musica musica) throws SQLException {
		// prepared statement para atualizacao

		String sql = "update Musicas set txtletra=?, ultimaAtualizacao=? where codmusica=?";
		PreparedStatement stmt = con.prepareStatement(sql);

		// seta os valores
		stmt.setString(1, musica.getTxtletra());
		stmt.setObject(2, new Timestamp(Calendar.getInstance()
				.getTimeInMillis()));
		stmt.setLong(3, musica.getCodmusica());

		// executa
		stmt.execute();
		stmt.close();
	}

}
